Module errors

Module errors 

Common error messages and error handling utilities

Constants

ERR_AMBIGUOUS_TIME
Error message for ambiguous local time
ERR_DATE_CALC_ERROR
Error message for date calculation errors
ERR_DATE_CALC_INVALID
Error message for invalid date calculation
ERR_INVALID_DATE
Error message for invalid date
ERR_INVALID_TIME
Error message for invalid time
ERR_MIDNIGHT_FAILED
Error message for failed midnight time creation
ERR_MONTH_POSITIVE
Error message for when month amount must be positive
ERR_RELATIVE_AMOUNT_NON_NEGATIVE
Error message for negative relative amounts
ERR_TIMEZONE_CONVERSION
Error message for timezone conversion errors
ERR_YEAR_OVERFLOW
Error message for year calculation overflow
ERR_YEAR_POSITIVE
Error message for when year amount must be positive

Functions

format_invalid_date
Format error message for invalid date with components
format_invalid_time
Format error message for invalid time with components
format_invalid_timezone_offset
Format error message for invalid timezone offset