Module time_utils

Module time_utils 

Time conversion and calculation utilities

Functions

calculate_timezone_offset_seconds
Calculate total seconds for a timezone offset
calculate_weekday_offset
Calculate the day offset for weekday calculations
convert_12_to_24_hour
Convert 12-hour time format to 24-hour format
is_valid_24_hour_time
Check whether the time components form a valid 24-hour clock time.
is_valid_calendar_date
Check whether the date components form a real calendar date.
is_valid_time
Check whether time components are valid for either 24-hour or AM/PM notation.
is_valid_timezone_offset
Check whether a timezone offset is in the supported UTC-12:00..=UTC+14:00 range.