TimeExpression

Enum TimeExpression 

pub enum TimeExpression {
    Now,
    Relative(RelativeTime),
    Absolute(AbsoluteTime),
    Day(DayReference),
    Time(Time),
    Date(StandardDate),
    DayTime(DayTime),
}
Represents a parsed time expression.

This is the main output type of the parsing functions. It can represent various forms of time expressions from natural language input.

Examples

use temps_core::{parse, Language, TimeExpression};

// "now" -> TimeExpression::Now
// "in 5 minutes" -> TimeExpression::Relative(...)
// "2024-01-15T14:30:00Z" -> TimeExpression::Absolute(...)
// "tomorrow" -> TimeExpression::Day(...)
// "3:30 pm" -> TimeExpression::Time(...)
// "tomorrow at 3:30 pm" -> TimeExpression::DayTime(...)

Variants



Now

The current moment in time (e.g., “now”, “jetzt”)



Relative(RelativeTime)

A time relative to now (e.g., “in 5 minutes”, “3 days ago”)



Absolute(AbsoluteTime)

An absolute date/time (e.g., “2024-01-15T14:30:00Z”)



Day(DayReference)

A day reference (e.g., “tomorrow”, “next Monday”)



Time(Time)

A time of day (e.g., “3:30 pm”, “14:30”)



Date(StandardDate)

A calendar date (e.g., “15/03/2024”, “31-12-2025”)



DayTime(DayTime)

A day with a specific time (e.g., “tomorrow at 3:30 pm”)