Common error messages and error handling utilities
Constants
- ERR_
AMBIGUOUS_ TIME - Error message for ambiguous local time
- ERR_
DATE_ CALC_ ERROR - Error message for date calculation errors
- ERR_
DATE_ CALC_ INVALID - Error message for invalid date calculation
- ERR_
INVALID_ DATE - Error message for invalid date
- ERR_
INVALID_ TIME - Error message for invalid time
- ERR_
MIDNIGHT_ FAILED - Error message for failed midnight time creation
- ERR_
MONTH_ POSITIVE - Error message for when month amount must be positive
- ERR_
RELATIVE_ AMOUNT_ NON_ NEGATIVE - Error message for negative relative amounts
- ERR_
TIMEZONE_ CONVERSION - Error message for timezone conversion errors
- ERR_
YEAR_ OVERFLOW - Error message for year calculation overflow
- ERR_
YEAR_ POSITIVE - Error message for when year amount must be positive
Functions
- format_
invalid_ date - Format error message for invalid date with components
- format_
invalid_ time - Format error message for invalid time with components
- format_
invalid_ timezone_ offset - Format error message for invalid timezone offset